# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignOptInHistoryDetailsContent(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action_type': 'str',
        'reason': 'str',
        'created_date': 'int',
        'email': 'str'
    }

    attribute_map = {
        'action_type': 'actionType',
        'reason': 'reason',
        'created_date': 'createdDate',
        'email': 'email'
    }

    def __init__(self, action_type=None, reason=None, created_date=None, email=None):  # noqa: E501
        """EmailCampaignOptInHistoryDetailsContent - a model defined in Swagger"""  # noqa: E501
        self._action_type = None
        self._reason = None
        self._created_date = None
        self._email = None
        self.discriminator = None
        self.action_type = action_type
        self.reason = reason
        self.created_date = created_date
        self.email = email

    @property
    def action_type(self):
        """Gets the action_type of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501

        The type of action associated with the email campaign OptIn History.  # noqa: E501

        :return: The action_type of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this EmailCampaignOptInHistoryDetailsContent.

        The type of action associated with the email campaign OptIn History.  # noqa: E501

        :param action_type: The action_type of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :type: str
        """
        if action_type is None:
            raise ValueError("Invalid value for `action_type`, must not be `None`")  # noqa: E501

        self._action_type = action_type

    @property
    def reason(self):
        """Gets the reason of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501

        The reason for the action in the email campaign OptIn History.  # noqa: E501

        :return: The reason of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this EmailCampaignOptInHistoryDetailsContent.

        The reason for the action in the email campaign OptIn History.  # noqa: E501

        :param reason: The reason of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :type: str
        """
        if reason is None:
            raise ValueError("Invalid value for `reason`, must not be `None`")  # noqa: E501

        self._reason = reason

    @property
    def created_date(self):
        """Gets the created_date of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501

        Timestamp representing the creation date of the email campaign OptIn History entry.  # noqa: E501

        :return: The created_date of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EmailCampaignOptInHistoryDetailsContent.

        Timestamp representing the creation date of the email campaign OptIn History entry.  # noqa: E501

        :param created_date: The created_date of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :type: int
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def email(self):
        """Gets the email of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501

        Email associated with the email campaign OptIn History.  # noqa: E501

        :return: The email of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this EmailCampaignOptInHistoryDetailsContent.

        Email associated with the email campaign OptIn History.  # noqa: E501

        :param email: The email of this EmailCampaignOptInHistoryDetailsContent.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignOptInHistoryDetailsContent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignOptInHistoryDetailsContent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    communications-email

    These APIs ensures an easy integration process of email management for developers to send, read, and track email histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ForwardProfileRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'subject': 'str',
        'to_email': 'str',
        'candidate_email': 'str'
    }

    attribute_map = {
        'subject': 'subject',
        'to_email': 'toEmail',
        'candidate_email': 'candidateEmail'
    }

    def __init__(self, subject=None, to_email=None, candidate_email=None):  # noqa: E501
        """ForwardProfileRequest - a model defined in Swagger"""  # noqa: E501
        self._subject = None
        self._to_email = None
        self._candidate_email = None
        self.discriminator = None
        self.subject = subject
        self.to_email = to_email
        self.candidate_email = candidate_email

    @property
    def subject(self):
        """Gets the subject of this ForwardProfileRequest.  # noqa: E501

        Subject for the Forward profile Request.  # noqa: E501

        :return: The subject of this ForwardProfileRequest.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this ForwardProfileRequest.

        Subject for the Forward profile Request.  # noqa: E501

        :param subject: The subject of this ForwardProfileRequest.  # noqa: E501
        :type: str
        """
        if subject is None:
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def to_email(self):
        """Gets the to_email of this ForwardProfileRequest.  # noqa: E501

        Recipient's email address.  # noqa: E501

        :return: The to_email of this ForwardProfileRequest.  # noqa: E501
        :rtype: str
        """
        return self._to_email

    @to_email.setter
    def to_email(self, to_email):
        """Sets the to_email of this ForwardProfileRequest.

        Recipient's email address.  # noqa: E501

        :param to_email: The to_email of this ForwardProfileRequest.  # noqa: E501
        :type: str
        """
        if to_email is None:
            raise ValueError("Invalid value for `to_email`, must not be `None`")  # noqa: E501

        self._to_email = to_email

    @property
    def candidate_email(self):
        """Gets the candidate_email of this ForwardProfileRequest.  # noqa: E501

        Candidate's email address.  # noqa: E501

        :return: The candidate_email of this ForwardProfileRequest.  # noqa: E501
        :rtype: str
        """
        return self._candidate_email

    @candidate_email.setter
    def candidate_email(self, candidate_email):
        """Sets the candidate_email of this ForwardProfileRequest.

        Candidate's email address.  # noqa: E501

        :param candidate_email: The candidate_email of this ForwardProfileRequest.  # noqa: E501
        :type: str
        """
        if candidate_email is None:
            raise ValueError("Invalid value for `candidate_email`, must not be `None`")  # noqa: E501

        self._candidate_email = candidate_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForwardProfileRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForwardProfileRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class RecommendationsApi(object):
    base_path = "/jobs-api/v1/jobs/recommendation"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def near_by_jobs(self, latitude, longitude, **kwargs):  # noqa: E501
        """Nearby Jobs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.near_by_jobs(latitude, longitude, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float latitude: Latitude value of the user's location. (required)
        :param float longitude: Longitude value of the user's location. (required)
        :param float radius: Radius in miles within which the job recommendations should be provided.
        :return: NearByJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.near_by_jobs_with_http_info(latitude, longitude, **kwargs)  # noqa: E501
        else:
            (data) = self.near_by_jobs_with_http_info(latitude, longitude, **kwargs)  # noqa: E501
            return data

    def near_by_jobs_with_http_info(self, latitude, longitude, **kwargs):  # noqa: E501
        """Nearby Jobs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.near_by_jobs_with_http_info(latitude, longitude, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param float latitude: Latitude value of the user's location. (required)
        :param float longitude: Longitude value of the user's location. (required)
        :param float radius: Radius in miles within which the job recommendations should be provided.
        :return: NearByJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['latitude', 'longitude', 'radius']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method near_by_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'latitude' is set
        if ('latitude' not in params or
                params['latitude'] is None):
            raise ValueError("Missing the required parameter `latitude` when calling `near_by_jobs`")  # noqa: E501
        # verify the required parameter 'longitude' is set
        if ('longitude' not in params or
                params['longitude'] is None):
            raise ValueError("Missing the required parameter `longitude` when calling `near_by_jobs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'latitude' in params:
            query_params.append(('latitude', params['latitude']))  # noqa: E501
        if 'longitude' in params:
            query_params.append(('longitude', params['longitude']))  # noqa: E501
        if 'radius' in params:
            query_params.append(('radius', params['radius']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/nearby', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NearByJobsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def profile_recommendations(self, body, **kwargs):  # noqa: E501
        """Profile Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.profile_recommendations(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobRecommendation body: (required)
        :return: ProfileMatchingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.profile_recommendations_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.profile_recommendations_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def profile_recommendations_with_http_info(self, body, **kwargs):  # noqa: E501
        """Profile Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.profile_recommendations_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param JobRecommendation body: (required)
        :return: ProfileMatchingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method profile_recommendations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `profile_recommendations`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/profilematched', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileMatchingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def similar_jobs(self, body, job_id, **kwargs):  # noqa: E501
        """Similar Jobs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.similar_jobs(body, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SimilarJobsRequest body: (required)
        :param str job_id: Job ID - unique field to identify the job. (required)
        :return: SimilarJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.similar_jobs_with_http_info(body, job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.similar_jobs_with_http_info(body, job_id, **kwargs)  # noqa: E501
            return data

    def similar_jobs_with_http_info(self, body, job_id, **kwargs):  # noqa: E501
        """Similar Jobs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.similar_jobs_with_http_info(body, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SimilarJobsRequest body: (required)
        :param str job_id: Job ID - unique field to identify the job. (required)
        :return: SimilarJobsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method similar_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `similar_jobs`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `similar_jobs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'job_id' in params:
            query_params.append(('jobId', params['job_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/similarjobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SimilarJobsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ApplicantsDataContacts(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'original_number': 'str',
        'phone_number': 'str',
        'phone_number_without_country_code': 'str',
        'country_code': 'str'
    }

    attribute_map = {
        'original_number': 'originalNumber',
        'phone_number': 'phoneNumber',
        'phone_number_without_country_code': 'phoneNumberWithoutCountryCode',
        'country_code': 'countryCode'
    }

    def __init__(self, original_number=None, phone_number=None, phone_number_without_country_code=None, country_code=None):  # noqa: E501
        """ApplicantsDataContacts - a model defined in Swagger"""  # noqa: E501
        self._original_number = None
        self._phone_number = None
        self._phone_number_without_country_code = None
        self._country_code = None
        self.discriminator = None
        if original_number is not None:
            self.original_number = original_number
        if phone_number is not None:
            self.phone_number = phone_number
        if phone_number_without_country_code is not None:
            self.phone_number_without_country_code = phone_number_without_country_code
        if country_code is not None:
            self.country_code = country_code

    @property
    def original_number(self):
        """Gets the original_number of this ApplicantsDataContacts.  # noqa: E501

        The phone number of the contact.  # noqa: E501

        :return: The original_number of this ApplicantsDataContacts.  # noqa: E501
        :rtype: str
        """
        return self._original_number

    @original_number.setter
    def original_number(self, original_number):
        """Sets the original_number of this ApplicantsDataContacts.

        The phone number of the contact.  # noqa: E501

        :param original_number: The original_number of this ApplicantsDataContacts.  # noqa: E501
        :type: str
        """

        self._original_number = original_number

    @property
    def phone_number(self):
        """Gets the phone_number of this ApplicantsDataContacts.  # noqa: E501

        The phone number of the contact.  # noqa: E501

        :return: The phone_number of this ApplicantsDataContacts.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ApplicantsDataContacts.

        The phone number of the contact.  # noqa: E501

        :param phone_number: The phone_number of this ApplicantsDataContacts.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def phone_number_without_country_code(self):
        """Gets the phone_number_without_country_code of this ApplicantsDataContacts.  # noqa: E501

        The phone number without country code  # noqa: E501

        :return: The phone_number_without_country_code of this ApplicantsDataContacts.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_without_country_code

    @phone_number_without_country_code.setter
    def phone_number_without_country_code(self, phone_number_without_country_code):
        """Sets the phone_number_without_country_code of this ApplicantsDataContacts.

        The phone number without country code  # noqa: E501

        :param phone_number_without_country_code: The phone_number_without_country_code of this ApplicantsDataContacts.  # noqa: E501
        :type: str
        """

        self._phone_number_without_country_code = phone_number_without_country_code

    @property
    def country_code(self):
        """Gets the country_code of this ApplicantsDataContacts.  # noqa: E501

        The country code associated with the contact.  # noqa: E501

        :return: The country_code of this ApplicantsDataContacts.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this ApplicantsDataContacts.

        The country code associated with the contact.  # noqa: E501

        :param country_code: The country_code of this ApplicantsDataContacts.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicantsDataContacts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicantsDataContacts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.aisourcing.ai_matching_api import AIMatchingApi


class AIMatching(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    # ai-sourcing apis
    def ai_matching_api(self):
        return AIMatchingApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

# flake8: noqa

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.recommendation.recommendations_api import RecommendationsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.recommendation.models.bad_request import BadRequest
from phenom.api.recommendation.models.error_response import ErrorResponse
from phenom.api.recommendation.models.job_node import JobNode
from phenom.api.recommendation.models.job_recommendation import JobRecommendation
from phenom.api.recommendation.models.near_by_jobs_response import NearByJobsResponse
from phenom.api.recommendation.models.near_by_jobs_response_data import NearByJobsResponseData
from phenom.api.recommendation.models.preferred_locations import PreferredLocations
from phenom.api.recommendation.models.preferred_locations_latlong import PreferredLocationsLatlong
from phenom.api.recommendation.models.profile_matching_response import ProfileMatchingResponse
from phenom.api.recommendation.models.profile_matching_response_jobs import ProfileMatchingResponseJobs
from phenom.api.recommendation.models.profile_matching_response_location_data import ProfileMatchingResponseLocationData
from phenom.api.recommendation.models.profile_matching_response_skill_gap import ProfileMatchingResponseSkillGap
from phenom.api.recommendation.models.similar_jobs_request import SimilarJobsRequest
from phenom.api.recommendation.models.similar_jobs_response import SimilarJobsResponse
from phenom.api.recommendation.models.similar_jobs_response_data import SimilarJobsResponseData
from phenom.api.recommendation.models.similar_jobs_response_data_similar_jobs import SimilarJobsResponseDataSimilarJobs
from phenom.api.recommendation.models.user_profile import UserProfile



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EducationDataEducations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'degree': 'str',
        'field_of_study': 'str',
        'school_name': 'str',
        'school_and_university': 'str',
        'state': 'str',
        'country': 'str',
        'start_date': 'float',
        'end_date': 'float',
        'is_high_education': 'bool'
    }

    attribute_map = {
        'degree': 'degree',
        'field_of_study': 'fieldOfStudy',
        'school_name': 'schoolName',
        'school_and_university': 'schoolAndUniversity',
        'state': 'state',
        'country': 'country',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'is_high_education': 'isHighEducation'
    }

    def __init__(self, degree=None, field_of_study=None, school_name=None, school_and_university=None, state=None, country=None, start_date=None, end_date=None, is_high_education=None):  # noqa: E501
        """EducationDataEducations - a model defined in Swagger"""  # noqa: E501
        self._degree = None
        self._field_of_study = None
        self._school_name = None
        self._school_and_university = None
        self._state = None
        self._country = None
        self._start_date = None
        self._end_date = None
        self._is_high_education = None
        self.discriminator = None
        if degree is not None:
            self.degree = degree
        if field_of_study is not None:
            self.field_of_study = field_of_study
        if school_name is not None:
            self.school_name = school_name
        if school_and_university is not None:
            self.school_and_university = school_and_university
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if is_high_education is not None:
            self.is_high_education = is_high_education

    @property
    def degree(self):
        """Gets the degree of this EducationDataEducations.  # noqa: E501

        The degree obtained by the candidate in their educational background.  # noqa: E501

        :return: The degree of this EducationDataEducations.  # noqa: E501
        :rtype: str
        """
        return self._degree

    @degree.setter
    def degree(self, degree):
        """Sets the degree of this EducationDataEducations.

        The degree obtained by the candidate in their educational background.  # noqa: E501

        :param degree: The degree of this EducationDataEducations.  # noqa: E501
        :type: str
        """

        self._degree = degree

    @property
    def field_of_study(self):
        """Gets the field_of_study of this EducationDataEducations.  # noqa: E501

        The field of study or major in the candidate's educational background.  # noqa: E501

        :return: The field_of_study of this EducationDataEducations.  # noqa: E501
        :rtype: str
        """
        return self._field_of_study

    @field_of_study.setter
    def field_of_study(self, field_of_study):
        """Sets the field_of_study of this EducationDataEducations.

        The field of study or major in the candidate's educational background.  # noqa: E501

        :param field_of_study: The field_of_study of this EducationDataEducations.  # noqa: E501
        :type: str
        """

        self._field_of_study = field_of_study

    @property
    def school_name(self):
        """Gets the school_name of this EducationDataEducations.  # noqa: E501

        The name of the school associated with the candidate's educational background.  # noqa: E501

        :return: The school_name of this EducationDataEducations.  # noqa: E501
        :rtype: str
        """
        return self._school_name

    @school_name.setter
    def school_name(self, school_name):
        """Sets the school_name of this EducationDataEducations.

        The name of the school associated with the candidate's educational background.  # noqa: E501

        :param school_name: The school_name of this EducationDataEducations.  # noqa: E501
        :type: str
        """

        self._school_name = school_name

    @property
    def school_and_university(self):
        """Gets the school_and_university of this EducationDataEducations.  # noqa: E501

        Combined name of the school and university associated with the candidate's educational background.  # noqa: E501

        :return: The school_and_university of this EducationDataEducations.  # noqa: E501
        :rtype: str
        """
        return self._school_and_university

    @school_and_university.setter
    def school_and_university(self, school_and_university):
        """Sets the school_and_university of this EducationDataEducations.

        Combined name of the school and university associated with the candidate's educational background.  # noqa: E501

        :param school_and_university: The school_and_university of this EducationDataEducations.  # noqa: E501
        :type: str
        """

        self._school_and_university = school_and_university

    @property
    def state(self):
        """Gets the state of this EducationDataEducations.  # noqa: E501

        The state where the educational institution is located.  # noqa: E501

        :return: The state of this EducationDataEducations.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this EducationDataEducations.

        The state where the educational institution is located.  # noqa: E501

        :param state: The state of this EducationDataEducations.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this EducationDataEducations.  # noqa: E501

        The country where the educational institution is located.  # noqa: E501

        :return: The country of this EducationDataEducations.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this EducationDataEducations.

        The country where the educational institution is located.  # noqa: E501

        :param country: The country of this EducationDataEducations.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def start_date(self):
        """Gets the start_date of this EducationDataEducations.  # noqa: E501

        The start date of the educational program.  # noqa: E501

        :return: The start_date of this EducationDataEducations.  # noqa: E501
        :rtype: float
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this EducationDataEducations.

        The start date of the educational program.  # noqa: E501

        :param start_date: The start_date of this EducationDataEducations.  # noqa: E501
        :type: float
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this EducationDataEducations.  # noqa: E501

        The end date of the educational program.  # noqa: E501

        :return: The end_date of this EducationDataEducations.  # noqa: E501
        :rtype: float
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this EducationDataEducations.

        The end date of the educational program.  # noqa: E501

        :param end_date: The end_date of this EducationDataEducations.  # noqa: E501
        :type: float
        """

        self._end_date = end_date

    @property
    def is_high_education(self):
        """Gets the is_high_education of this EducationDataEducations.  # noqa: E501

        Boolean indicating whether the education is considered high education or not.  # noqa: E501

        :return: The is_high_education of this EducationDataEducations.  # noqa: E501
        :rtype: bool
        """
        return self._is_high_education

    @is_high_education.setter
    def is_high_education(self, is_high_education):
        """Sets the is_high_education of this EducationDataEducations.

        Boolean indicating whether the education is considered high education or not.  # noqa: E501

        :param is_high_education: The is_high_education of this EducationDataEducations.  # noqa: E501
        :type: bool
        """

        self._is_high_education = is_high_education

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EducationDataEducations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EducationDataEducations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class CandidateInviteApi(object):
    base_path = "/interview-screening"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def disable_interview(self, body, **kwargs):  # noqa: E501
        """Disable Interview  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_interview(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DisableInterviewRequest body: (required)
        :return: DisableInterviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_interview_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.disable_interview_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def disable_interview_with_http_info(self, body, **kwargs):  # noqa: E501
        """Disable Interview  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_interview_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DisableInterviewRequest body: (required)
        :return: DisableInterviewResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_interview" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `disable_interview`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/interview/disable', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DisableInterviewResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_assessment_by_id(self, interview_id, **kwargs):  # noqa: E501
        """Get Interview Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assessment_by_id(interview_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str interview_id: (required)
        :return: GetInterviewDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_assessment_by_id_with_http_info(interview_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_assessment_by_id_with_http_info(interview_id, **kwargs)  # noqa: E501
            return data

    def get_assessment_by_id_with_http_info(self, interview_id, **kwargs):  # noqa: E501
        """Get Interview Details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assessment_by_id_with_http_info(interview_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str interview_id: (required)
        :return: GetInterviewDetailsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['interview_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_assessment_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'interview_id' is set
        if ('interview_id' not in params or
                params['interview_id'] is None):
            raise ValueError("Missing the required parameter `interview_id` when calling `get_assessment_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'interview_id' in params:
            path_params['interviewId'] = params['interview_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/interview/{interviewId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetInterviewDetailsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_interviews_for_candidate(self, candidate_id, **kwargs):  # noqa: E501
        """Get Details By CandidateId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_interviews_for_candidate(candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: (required)
        :return: GetAllInterviewsForCandidateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_interviews_for_candidate_with_http_info(candidate_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_interviews_for_candidate_with_http_info(candidate_id, **kwargs)  # noqa: E501
            return data

    def get_interviews_for_candidate_with_http_info(self, candidate_id, **kwargs):  # noqa: E501
        """Get Details By CandidateId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_interviews_for_candidate_with_http_info(candidate_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: (required)
        :return: GetAllInterviewsForCandidateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_interviews_for_candidate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_interviews_for_candidate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/interview/candidates/{candidateId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAllInterviewsForCandidateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_interviews_for_job(self, job_id, **kwargs):  # noqa: E501
        """Get Interviews For JobId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_interviews_for_job(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: (required)
        :return: GetAllInterviewsForJobIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_interviews_for_job_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_interviews_for_job_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def get_interviews_for_job_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """Get Interviews For JobId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_interviews_for_job_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: (required)
        :return: GetAllInterviewsForJobIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_interviews_for_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_interviews_for_job`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/interview/jobs/{jobId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAllInterviewsForJobIdResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invite_candidate_for_video_assessment(self, body, **kwargs):  # noqa: E501
        """Invite Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invite_candidate_for_video_assessment(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param InviteCandidate body: (required)
        :return: InviteCandidateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.invite_candidate_for_video_assessment_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.invite_candidate_for_video_assessment_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def invite_candidate_for_video_assessment_with_http_info(self, body, **kwargs):  # noqa: E501
        """Invite Candidate  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invite_candidate_for_video_assessment_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param InviteCandidate body: (required)
        :return: InviteCandidateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_candidate_for_video_assessment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `invite_candidate_for_video_assessment`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/interview', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InviteCandidateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsTenantSpecificAdditionalFields(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_classification': 'str',
        'maximumsalary': 'str',
        'minimumsalary': 'float',
        'pay_rate': 'str',
        'shift_details': 'str',
        'custom_ref_id': 'str',
        'is_remote': 'float',
        'worker_type': 'str',
        'store_number': 'str',
        'job_profile_id': 'str'
    }

    attribute_map = {
        'job_classification': 'jobClassification',
        'maximumsalary': 'maximumsalary',
        'minimumsalary': 'minimumsalary',
        'pay_rate': 'payRate',
        'shift_details': 'shiftDetails',
        'custom_ref_id': 'customRefId',
        'is_remote': 'isRemote',
        'worker_type': 'workerType',
        'store_number': 'storeNumber',
        'job_profile_id': 'jobProfileId'
    }

    def __init__(self, job_classification=None, maximumsalary=None, minimumsalary=None, pay_rate=None, shift_details=None, custom_ref_id=None, is_remote=None, worker_type=None, store_number=None, job_profile_id=None):  # noqa: E501
        """JobDetailsTenantSpecificAdditionalFields - a model defined in Swagger"""  # noqa: E501
        self._job_classification = None
        self._maximumsalary = None
        self._minimumsalary = None
        self._pay_rate = None
        self._shift_details = None
        self._custom_ref_id = None
        self._is_remote = None
        self._worker_type = None
        self._store_number = None
        self._job_profile_id = None
        self.discriminator = None
        if job_classification is not None:
            self.job_classification = job_classification
        if maximumsalary is not None:
            self.maximumsalary = maximumsalary
        if minimumsalary is not None:
            self.minimumsalary = minimumsalary
        if pay_rate is not None:
            self.pay_rate = pay_rate
        if shift_details is not None:
            self.shift_details = shift_details
        if custom_ref_id is not None:
            self.custom_ref_id = custom_ref_id
        if is_remote is not None:
            self.is_remote = is_remote
        if worker_type is not None:
            self.worker_type = worker_type
        if store_number is not None:
            self.store_number = store_number
        if job_profile_id is not None:
            self.job_profile_id = job_profile_id

    @property
    def job_classification(self):
        """Gets the job_classification of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Classification of the job.  # noqa: E501

        :return: The job_classification of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._job_classification

    @job_classification.setter
    def job_classification(self, job_classification):
        """Sets the job_classification of this JobDetailsTenantSpecificAdditionalFields.

        Classification of the job.  # noqa: E501

        :param job_classification: The job_classification of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._job_classification = job_classification

    @property
    def maximumsalary(self):
        """Gets the maximumsalary of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Maximum salary offered for the job.  # noqa: E501

        :return: The maximumsalary of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._maximumsalary

    @maximumsalary.setter
    def maximumsalary(self, maximumsalary):
        """Sets the maximumsalary of this JobDetailsTenantSpecificAdditionalFields.

        Maximum salary offered for the job.  # noqa: E501

        :param maximumsalary: The maximumsalary of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._maximumsalary = maximumsalary

    @property
    def minimumsalary(self):
        """Gets the minimumsalary of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Minimum salary offered for the job.  # noqa: E501

        :return: The minimumsalary of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: float
        """
        return self._minimumsalary

    @minimumsalary.setter
    def minimumsalary(self, minimumsalary):
        """Sets the minimumsalary of this JobDetailsTenantSpecificAdditionalFields.

        Minimum salary offered for the job.  # noqa: E501

        :param minimumsalary: The minimumsalary of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: float
        """

        self._minimumsalary = minimumsalary

    @property
    def pay_rate(self):
        """Gets the pay_rate of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Pay rate of the job.  # noqa: E501

        :return: The pay_rate of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._pay_rate

    @pay_rate.setter
    def pay_rate(self, pay_rate):
        """Sets the pay_rate of this JobDetailsTenantSpecificAdditionalFields.

        Pay rate of the job.  # noqa: E501

        :param pay_rate: The pay_rate of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._pay_rate = pay_rate

    @property
    def shift_details(self):
        """Gets the shift_details of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Shift details of the job.  # noqa: E501

        :return: The shift_details of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._shift_details

    @shift_details.setter
    def shift_details(self, shift_details):
        """Sets the shift_details of this JobDetailsTenantSpecificAdditionalFields.

        Shift details of the job.  # noqa: E501

        :param shift_details: The shift_details of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._shift_details = shift_details

    @property
    def custom_ref_id(self):
        """Gets the custom_ref_id of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Custom reference ID of the job.  # noqa: E501

        :return: The custom_ref_id of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._custom_ref_id

    @custom_ref_id.setter
    def custom_ref_id(self, custom_ref_id):
        """Sets the custom_ref_id of this JobDetailsTenantSpecificAdditionalFields.

        Custom reference ID of the job.  # noqa: E501

        :param custom_ref_id: The custom_ref_id of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._custom_ref_id = custom_ref_id

    @property
    def is_remote(self):
        """Gets the is_remote of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Whether it's a remote job.  # noqa: E501

        :return: The is_remote of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: float
        """
        return self._is_remote

    @is_remote.setter
    def is_remote(self, is_remote):
        """Sets the is_remote of this JobDetailsTenantSpecificAdditionalFields.

        Whether it's a remote job.  # noqa: E501

        :param is_remote: The is_remote of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: float
        """

        self._is_remote = is_remote

    @property
    def worker_type(self):
        """Gets the worker_type of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Worker type.  # noqa: E501

        :return: The worker_type of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._worker_type

    @worker_type.setter
    def worker_type(self, worker_type):
        """Sets the worker_type of this JobDetailsTenantSpecificAdditionalFields.

        Worker type.  # noqa: E501

        :param worker_type: The worker_type of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._worker_type = worker_type

    @property
    def store_number(self):
        """Gets the store_number of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Store number of the job.  # noqa: E501

        :return: The store_number of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._store_number

    @store_number.setter
    def store_number(self, store_number):
        """Sets the store_number of this JobDetailsTenantSpecificAdditionalFields.

        Store number of the job.  # noqa: E501

        :param store_number: The store_number of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._store_number = store_number

    @property
    def job_profile_id(self):
        """Gets the job_profile_id of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501

        Job's profile ID.  # noqa: E501

        :return: The job_profile_id of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :rtype: str
        """
        return self._job_profile_id

    @job_profile_id.setter
    def job_profile_id(self, job_profile_id):
        """Sets the job_profile_id of this JobDetailsTenantSpecificAdditionalFields.

        Job's profile ID.  # noqa: E501

        :param job_profile_id: The job_profile_id of this JobDetailsTenantSpecificAdditionalFields.  # noqa: E501
        :type: str
        """

        self._job_profile_id = job_profile_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsTenantSpecificAdditionalFields, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsTenantSpecificAdditionalFields):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class PreferredLocationsLatlong(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lon': 'float',
        'lan': 'float'
    }

    attribute_map = {
        'lon': 'lon',
        'lan': 'lan'
    }

    def __init__(self, lon=None, lan=None):  # noqa: E501
        """PreferredLocationsLatlong - a model defined in Swagger"""  # noqa: E501
        self._lon = None
        self._lan = None
        self.discriminator = None
        if lon is not None:
            self.lon = lon
        if lan is not None:
            self.lan = lan

    @property
    def lon(self):
        """Gets the lon of this PreferredLocationsLatlong.  # noqa: E501

        Longitude of the preferred location provided by user.  # noqa: E501

        :return: The lon of this PreferredLocationsLatlong.  # noqa: E501
        :rtype: float
        """
        return self._lon

    @lon.setter
    def lon(self, lon):
        """Sets the lon of this PreferredLocationsLatlong.

        Longitude of the preferred location provided by user.  # noqa: E501

        :param lon: The lon of this PreferredLocationsLatlong.  # noqa: E501
        :type: float
        """

        self._lon = lon

    @property
    def lan(self):
        """Gets the lan of this PreferredLocationsLatlong.  # noqa: E501

        Latitude of the preferred location provided by user.  # noqa: E501

        :return: The lan of this PreferredLocationsLatlong.  # noqa: E501
        :rtype: float
        """
        return self._lan

    @lan.setter
    def lan(self, lan):
        """Sets the lan of this PreferredLocationsLatlong.

        Latitude of the preferred location provided by user.  # noqa: E501

        :param lan: The lan of this PreferredLocationsLatlong.  # noqa: E501
        :type: float
        """

        self._lan = lan

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PreferredLocationsLatlong, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PreferredLocationsLatlong):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class LocationDTO(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'address': 'str',
        'postal_code': 'str'
    }

    attribute_map = {
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'address': 'address',
        'postal_code': 'postalCode'
    }

    def __init__(self, city=None, state=None, country=None, address=None, postal_code=None):  # noqa: E501
        """LocationDTO - a model defined in Swagger"""  # noqa: E501
        self._city = None
        self._state = None
        self._country = None
        self._address = None
        self._postal_code = None
        self.discriminator = None
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if address is not None:
            self.address = address
        if postal_code is not None:
            self.postal_code = postal_code

    @property
    def city(self):
        """Gets the city of this LocationDTO.  # noqa: E501

        ATS job posting city name.  # noqa: E501

        :return: The city of this LocationDTO.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this LocationDTO.

        ATS job posting city name.  # noqa: E501

        :param city: The city of this LocationDTO.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this LocationDTO.  # noqa: E501

        ATS job posting state name.  # noqa: E501

        :return: The state of this LocationDTO.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this LocationDTO.

        ATS job posting state name.  # noqa: E501

        :param state: The state of this LocationDTO.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this LocationDTO.  # noqa: E501

        ATS job posting country name.  # noqa: E501

        :return: The country of this LocationDTO.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this LocationDTO.

        ATS job posting country name.  # noqa: E501

        :param country: The country of this LocationDTO.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def address(self):
        """Gets the address of this LocationDTO.  # noqa: E501

        ATS job posting address.  # noqa: E501

        :return: The address of this LocationDTO.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this LocationDTO.

        ATS job posting address.  # noqa: E501

        :param address: The address of this LocationDTO.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def postal_code(self):
        """Gets the postal_code of this LocationDTO.  # noqa: E501

        ATS job posting location zip code.  # noqa: E501

        :return: The postal_code of this LocationDTO.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this LocationDTO.

        ATS job posting location zip code.  # noqa: E501

        :param postal_code: The postal_code of this LocationDTO.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    jobs-questionnarie-api

    These APIs streamline question management, providing tools to create, delete, and update questions. Additionally, they offer functionality to attach question lists to specific job profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.jobquestionnarie.models.bad_request_error import BadRequestError
from phenom.api.jobquestionnarie.models.bad_request_error_errors import BadRequestErrorErrors
from phenom.api.jobquestionnarie.models.create_job_questionnarie_request import CreateJobQuestionnarieRequest
from phenom.api.jobquestionnarie.models.create_job_questionnarie_request_options import CreateJobQuestionnarieRequestOptions
from phenom.api.jobquestionnarie.models.create_job_questionnarie_request_pre_screening_questions import CreateJobQuestionnarieRequestPreScreeningQuestions
from phenom.api.jobquestionnarie.models.create_questionnarie_templates_request import CreateQuestionnarieTemplatesRequest
from phenom.api.jobquestionnarie.models.create_questionnarie_templates_request_pre_screening_questions import CreateQuestionnarieTemplatesRequestPreScreeningQuestions
from phenom.api.jobquestionnarie.models.delete_questionnarie_template_response import DeleteQuestionnarieTemplateResponse
from phenom.api.jobquestionnarie.models.get_questionnarie_templates_response import GetQuestionnarieTemplatesResponse
from phenom.api.jobquestionnarie.models.get_questionnarie_templates_response_data import GetQuestionnarieTemplatesResponseData
from phenom.api.jobquestionnarie.models.get_questionnarie_templates_response_pagination import GetQuestionnarieTemplatesResponsePagination
from phenom.api.jobquestionnarie.models.internal_server_error_response import InternalServerErrorResponse
from phenom.api.jobquestionnarie.models.job_questionnarie_creation_response import JobQuestionnarieCreationResponse
from phenom.api.jobquestionnarie.models.no_content_response import NoContentResponse
from phenom.api.jobquestionnarie.models.not_found_error import NotFoundError
from phenom.api.jobquestionnarie.models.questionnarie_deletion_response import QuestionnarieDeletionResponse
from phenom.api.jobquestionnarie.models.questionnarie_template_creation_response import QuestionnarieTemplateCreationResponse
from phenom.api.jobquestionnarie.models.update_questionnaire_template_request import UpdateQuestionnaireTemplateRequest
from phenom.api.jobquestionnarie.models.update_questionnaire_template_request_pre_screening_questions import UpdateQuestionnaireTemplateRequestPreScreeningQuestions
from phenom.api.jobquestionnarie.models.update_template_response import UpdateTemplateResponse



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllQuestionTypesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'question_types': 'list[GetAllQuestionTypesDataQuestionTypes]',
        'duration_in_sec': 'list[float]',
        'character_count': 'list[float]',
        'multi_choice_settings': 'GetAllQuestionTypesDataMultiChoiceSettings',
        'knockout_question_configuration': 'list[GetAllQuestionTypesDataKnockoutQuestionConfiguration]'
    }

    attribute_map = {
        'question_types': 'questionTypes',
        'duration_in_sec': 'durationInSec',
        'character_count': 'characterCount',
        'multi_choice_settings': 'multiChoiceSettings',
        'knockout_question_configuration': 'knockoutQuestionConfiguration'
    }

    def __init__(self, question_types=None, duration_in_sec=None, character_count=None, multi_choice_settings=None, knockout_question_configuration=None):  # noqa: E501
        """GetAllQuestionTypesData - a model defined in Swagger"""  # noqa: E501
        self._question_types = None
        self._duration_in_sec = None
        self._character_count = None
        self._multi_choice_settings = None
        self._knockout_question_configuration = None
        self.discriminator = None
        self.question_types = question_types
        self.duration_in_sec = duration_in_sec
        self.character_count = character_count
        self.multi_choice_settings = multi_choice_settings
        self.knockout_question_configuration = knockout_question_configuration

    @property
    def question_types(self):
        """Gets the question_types of this GetAllQuestionTypesData.  # noqa: E501

        Contains all question types.  # noqa: E501

        :return: The question_types of this GetAllQuestionTypesData.  # noqa: E501
        :rtype: list[GetAllQuestionTypesDataQuestionTypes]
        """
        return self._question_types

    @question_types.setter
    def question_types(self, question_types):
        """Sets the question_types of this GetAllQuestionTypesData.

        Contains all question types.  # noqa: E501

        :param question_types: The question_types of this GetAllQuestionTypesData.  # noqa: E501
        :type: list[GetAllQuestionTypesDataQuestionTypes]
        """
        if question_types is None:
            raise ValueError("Invalid value for `question_types`, must not be `None`")  # noqa: E501

        self._question_types = question_types

    @property
    def duration_in_sec(self):
        """Gets the duration_in_sec of this GetAllQuestionTypesData.  # noqa: E501


        :return: The duration_in_sec of this GetAllQuestionTypesData.  # noqa: E501
        :rtype: list[float]
        """
        return self._duration_in_sec

    @duration_in_sec.setter
    def duration_in_sec(self, duration_in_sec):
        """Sets the duration_in_sec of this GetAllQuestionTypesData.


        :param duration_in_sec: The duration_in_sec of this GetAllQuestionTypesData.  # noqa: E501
        :type: list[float]
        """
        if duration_in_sec is None:
            raise ValueError("Invalid value for `duration_in_sec`, must not be `None`")  # noqa: E501

        self._duration_in_sec = duration_in_sec

    @property
    def character_count(self):
        """Gets the character_count of this GetAllQuestionTypesData.  # noqa: E501


        :return: The character_count of this GetAllQuestionTypesData.  # noqa: E501
        :rtype: list[float]
        """
        return self._character_count

    @character_count.setter
    def character_count(self, character_count):
        """Sets the character_count of this GetAllQuestionTypesData.


        :param character_count: The character_count of this GetAllQuestionTypesData.  # noqa: E501
        :type: list[float]
        """
        if character_count is None:
            raise ValueError("Invalid value for `character_count`, must not be `None`")  # noqa: E501

        self._character_count = character_count

    @property
    def multi_choice_settings(self):
        """Gets the multi_choice_settings of this GetAllQuestionTypesData.  # noqa: E501


        :return: The multi_choice_settings of this GetAllQuestionTypesData.  # noqa: E501
        :rtype: GetAllQuestionTypesDataMultiChoiceSettings
        """
        return self._multi_choice_settings

    @multi_choice_settings.setter
    def multi_choice_settings(self, multi_choice_settings):
        """Sets the multi_choice_settings of this GetAllQuestionTypesData.


        :param multi_choice_settings: The multi_choice_settings of this GetAllQuestionTypesData.  # noqa: E501
        :type: GetAllQuestionTypesDataMultiChoiceSettings
        """
        if multi_choice_settings is None:
            raise ValueError("Invalid value for `multi_choice_settings`, must not be `None`")  # noqa: E501

        self._multi_choice_settings = multi_choice_settings

    @property
    def knockout_question_configuration(self):
        """Gets the knockout_question_configuration of this GetAllQuestionTypesData.  # noqa: E501

        Knockout question UI parameters.  # noqa: E501

        :return: The knockout_question_configuration of this GetAllQuestionTypesData.  # noqa: E501
        :rtype: list[GetAllQuestionTypesDataKnockoutQuestionConfiguration]
        """
        return self._knockout_question_configuration

    @knockout_question_configuration.setter
    def knockout_question_configuration(self, knockout_question_configuration):
        """Sets the knockout_question_configuration of this GetAllQuestionTypesData.

        Knockout question UI parameters.  # noqa: E501

        :param knockout_question_configuration: The knockout_question_configuration of this GetAllQuestionTypesData.  # noqa: E501
        :type: list[GetAllQuestionTypesDataKnockoutQuestionConfiguration]
        """
        if knockout_question_configuration is None:
            raise ValueError("Invalid value for `knockout_question_configuration`, must not be `None`")  # noqa: E501

        self._knockout_question_configuration = knockout_question_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllQuestionTypesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllQuestionTypesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SkillMatchingResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'matching_skills': 'list[str]',
        'matching_skills_count': 'int',
        'unmatching_skills': 'list[str]',
        'unmatching_skills_count': 'int',
        'total_job_skills': 'int'
    }

    attribute_map = {
        'matching_skills': 'matchingSkills',
        'matching_skills_count': 'matchingSkillsCount',
        'unmatching_skills': 'unmatchingSkills',
        'unmatching_skills_count': 'unmatchingSkillsCount',
        'total_job_skills': 'totalJobSkills'
    }

    def __init__(self, matching_skills=None, matching_skills_count=None, unmatching_skills=None, unmatching_skills_count=None, total_job_skills=None):  # noqa: E501
        """SkillMatchingResponse - a model defined in Swagger"""  # noqa: E501
        self._matching_skills = None
        self._matching_skills_count = None
        self._unmatching_skills = None
        self._unmatching_skills_count = None
        self._total_job_skills = None
        self.discriminator = None
        if matching_skills is not None:
            self.matching_skills = matching_skills
        if matching_skills_count is not None:
            self.matching_skills_count = matching_skills_count
        if unmatching_skills is not None:
            self.unmatching_skills = unmatching_skills
        if unmatching_skills_count is not None:
            self.unmatching_skills_count = unmatching_skills_count
        if total_job_skills is not None:
            self.total_job_skills = total_job_skills

    @property
    def matching_skills(self):
        """Gets the matching_skills of this SkillMatchingResponse.  # noqa: E501

        List of matched skills.  # noqa: E501

        :return: The matching_skills of this SkillMatchingResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._matching_skills

    @matching_skills.setter
    def matching_skills(self, matching_skills):
        """Sets the matching_skills of this SkillMatchingResponse.

        List of matched skills.  # noqa: E501

        :param matching_skills: The matching_skills of this SkillMatchingResponse.  # noqa: E501
        :type: list[str]
        """

        self._matching_skills = matching_skills

    @property
    def matching_skills_count(self):
        """Gets the matching_skills_count of this SkillMatchingResponse.  # noqa: E501

        Count of matched skills.  # noqa: E501

        :return: The matching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :rtype: int
        """
        return self._matching_skills_count

    @matching_skills_count.setter
    def matching_skills_count(self, matching_skills_count):
        """Sets the matching_skills_count of this SkillMatchingResponse.

        Count of matched skills.  # noqa: E501

        :param matching_skills_count: The matching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :type: int
        """

        self._matching_skills_count = matching_skills_count

    @property
    def unmatching_skills(self):
        """Gets the unmatching_skills of this SkillMatchingResponse.  # noqa: E501

        List of unmatched skills.  # noqa: E501

        :return: The unmatching_skills of this SkillMatchingResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._unmatching_skills

    @unmatching_skills.setter
    def unmatching_skills(self, unmatching_skills):
        """Sets the unmatching_skills of this SkillMatchingResponse.

        List of unmatched skills.  # noqa: E501

        :param unmatching_skills: The unmatching_skills of this SkillMatchingResponse.  # noqa: E501
        :type: list[str]
        """

        self._unmatching_skills = unmatching_skills

    @property
    def unmatching_skills_count(self):
        """Gets the unmatching_skills_count of this SkillMatchingResponse.  # noqa: E501

        Count of unmatched skills.  # noqa: E501

        :return: The unmatching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :rtype: int
        """
        return self._unmatching_skills_count

    @unmatching_skills_count.setter
    def unmatching_skills_count(self, unmatching_skills_count):
        """Sets the unmatching_skills_count of this SkillMatchingResponse.

        Count of unmatched skills.  # noqa: E501

        :param unmatching_skills_count: The unmatching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :type: int
        """

        self._unmatching_skills_count = unmatching_skills_count

    @property
    def total_job_skills(self):
        """Gets the total_job_skills of this SkillMatchingResponse.  # noqa: E501

        Count of total job skills.  # noqa: E501

        :return: The total_job_skills of this SkillMatchingResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_job_skills

    @total_job_skills.setter
    def total_job_skills(self, total_job_skills):
        """Sets the total_job_skills of this SkillMatchingResponse.

        Count of total job skills.  # noqa: E501

        :param total_job_skills: The total_job_skills of this SkillMatchingResponse.  # noqa: E501
        :type: int
        """

        self._total_job_skills = total_job_skills

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SkillMatchingResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SkillMatchingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class RecommendationsDataRecommendations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_id': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'text': 'str',
        'type': 'str',
        'relation': 'str',
        'priority': 'str'
    }

    attribute_map = {
        'field_id': 'fieldID',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'text': 'text',
        'type': 'type',
        'relation': 'relation',
        'priority': 'priority'
    }

    def __init__(self, field_id=None, first_name=None, last_name=None, text=None, type=None, relation=None, priority=None):  # noqa: E501
        """RecommendationsDataRecommendations - a model defined in Swagger"""  # noqa: E501
        self._field_id = None
        self._first_name = None
        self._last_name = None
        self._text = None
        self._type = None
        self._relation = None
        self._priority = None
        self.discriminator = None
        if field_id is not None:
            self.field_id = field_id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if text is not None:
            self.text = text
        if type is not None:
            self.type = type
        if relation is not None:
            self.relation = relation
        if priority is not None:
            self.priority = priority

    @property
    def field_id(self):
        """Gets the field_id of this RecommendationsDataRecommendations.  # noqa: E501

        Unique identifier for the recommendation field.  # noqa: E501

        :return: The field_id of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this RecommendationsDataRecommendations.

        Unique identifier for the recommendation field.  # noqa: E501

        :param field_id: The field_id of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def first_name(self):
        """Gets the first_name of this RecommendationsDataRecommendations.  # noqa: E501

        First name of the person providing the recommendation.  # noqa: E501

        :return: The first_name of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this RecommendationsDataRecommendations.

        First name of the person providing the recommendation.  # noqa: E501

        :param first_name: The first_name of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this RecommendationsDataRecommendations.  # noqa: E501

        Last name of the person providing the recommendation.  # noqa: E501

        :return: The last_name of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this RecommendationsDataRecommendations.

        Last name of the person providing the recommendation.  # noqa: E501

        :param last_name: The last_name of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def text(self):
        """Gets the text of this RecommendationsDataRecommendations.  # noqa: E501

        Text or content of the recommendation.  # noqa: E501

        :return: The text of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this RecommendationsDataRecommendations.

        Text or content of the recommendation.  # noqa: E501

        :param text: The text of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def type(self):
        """Gets the type of this RecommendationsDataRecommendations.  # noqa: E501

        Type or category of the recommendation.  # noqa: E501

        :return: The type of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RecommendationsDataRecommendations.

        Type or category of the recommendation.  # noqa: E501

        :param type: The type of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def relation(self):
        """Gets the relation of this RecommendationsDataRecommendations.  # noqa: E501

        Relationship of the person providing the recommendation to the candidate.  # noqa: E501

        :return: The relation of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._relation

    @relation.setter
    def relation(self, relation):
        """Sets the relation of this RecommendationsDataRecommendations.

        Relationship of the person providing the recommendation to the candidate.  # noqa: E501

        :param relation: The relation of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._relation = relation

    @property
    def priority(self):
        """Gets the priority of this RecommendationsDataRecommendations.  # noqa: E501

        Priority of the recommendation.  # noqa: E501

        :return: The priority of this RecommendationsDataRecommendations.  # noqa: E501
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this RecommendationsDataRecommendations.

        Priority of the recommendation.  # noqa: E501

        :param priority: The priority of this RecommendationsDataRecommendations.  # noqa: E501
        :type: str
        """

        self._priority = priority

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RecommendationsDataRecommendations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecommendationsDataRecommendations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.resumeparser.resume_parsing_api import ResumeParsingApi
from phenom.api.jobparser.job_parsing_api import JobParsingApi

class Parsers(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    # resumeparser apis
    def resume_parsing_api(self):
        return ResumeParsingApi(self.__token, self.__gateway_url, self.__apikey)
    # job-parser apis
    def job_parsing_api(self):
        return JobParsingApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsHiringManagerList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'manager_email': 'str',
        'manager_id': 'str',
        'source': 'str',
        'manager_name': 'str'
    }

    attribute_map = {
        'manager_email': 'managerEmail',
        'manager_id': 'managerId',
        'source': 'source',
        'manager_name': 'managerName'
    }

    def __init__(self, manager_email=None, manager_id=None, source=None, manager_name=None):  # noqa: E501
        """JobDetailsHiringManagerList - a model defined in Swagger"""  # noqa: E501
        self._manager_email = None
        self._manager_id = None
        self._source = None
        self._manager_name = None
        self.discriminator = None
        if manager_email is not None:
            self.manager_email = manager_email
        if manager_id is not None:
            self.manager_id = manager_id
        if source is not None:
            self.source = source
        if manager_name is not None:
            self.manager_name = manager_name

    @property
    def manager_email(self):
        """Gets the manager_email of this JobDetailsHiringManagerList.  # noqa: E501

        Email address of the manager.  # noqa: E501

        :return: The manager_email of this JobDetailsHiringManagerList.  # noqa: E501
        :rtype: str
        """
        return self._manager_email

    @manager_email.setter
    def manager_email(self, manager_email):
        """Sets the manager_email of this JobDetailsHiringManagerList.

        Email address of the manager.  # noqa: E501

        :param manager_email: The manager_email of this JobDetailsHiringManagerList.  # noqa: E501
        :type: str
        """

        self._manager_email = manager_email

    @property
    def manager_id(self):
        """Gets the manager_id of this JobDetailsHiringManagerList.  # noqa: E501

        Unique ID of the manager.  # noqa: E501

        :return: The manager_id of this JobDetailsHiringManagerList.  # noqa: E501
        :rtype: str
        """
        return self._manager_id

    @manager_id.setter
    def manager_id(self, manager_id):
        """Sets the manager_id of this JobDetailsHiringManagerList.

        Unique ID of the manager.  # noqa: E501

        :param manager_id: The manager_id of this JobDetailsHiringManagerList.  # noqa: E501
        :type: str
        """

        self._manager_id = manager_id

    @property
    def source(self):
        """Gets the source of this JobDetailsHiringManagerList.  # noqa: E501

        Source from which the manager was added to this job.  # noqa: E501

        :return: The source of this JobDetailsHiringManagerList.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this JobDetailsHiringManagerList.

        Source from which the manager was added to this job.  # noqa: E501

        :param source: The source of this JobDetailsHiringManagerList.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def manager_name(self):
        """Gets the manager_name of this JobDetailsHiringManagerList.  # noqa: E501

        Name of the manager.  # noqa: E501

        :return: The manager_name of this JobDetailsHiringManagerList.  # noqa: E501
        :rtype: str
        """
        return self._manager_name

    @manager_name.setter
    def manager_name(self, manager_name):
        """Sets the manager_name of this JobDetailsHiringManagerList.

        Name of the manager.  # noqa: E501

        :param manager_name: The manager_name of this JobDetailsHiringManagerList.  # noqa: E501
        :type: str
        """

        self._manager_name = manager_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsHiringManagerList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsHiringManagerList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateCertificationRequestCertifications(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'certification_number': 'str',
        'name': 'str',
        'institute': 'str',
        'description': 'str',
        'state': 'str',
        'issued_date': 'UpdateCertificationRequestIssuedDate',
        'expiry_date': 'UpdateCertificationRequestExpiryDate'
    }

    attribute_map = {
        'certification_number': 'certificationNumber',
        'name': 'name',
        'institute': 'institute',
        'description': 'description',
        'state': 'state',
        'issued_date': 'issuedDate',
        'expiry_date': 'expiryDate'
    }

    def __init__(self, certification_number=None, name=None, institute=None, description=None, state=None, issued_date=None, expiry_date=None):  # noqa: E501
        """UpdateCertificationRequestCertifications - a model defined in Swagger"""  # noqa: E501
        self._certification_number = None
        self._name = None
        self._institute = None
        self._description = None
        self._state = None
        self._issued_date = None
        self._expiry_date = None
        self.discriminator = None
        if certification_number is not None:
            self.certification_number = certification_number
        if name is not None:
            self.name = name
        if institute is not None:
            self.institute = institute
        if description is not None:
            self.description = description
        if state is not None:
            self.state = state
        if issued_date is not None:
            self.issued_date = issued_date
        if expiry_date is not None:
            self.expiry_date = expiry_date

    @property
    def certification_number(self):
        """Gets the certification_number of this UpdateCertificationRequestCertifications.  # noqa: E501

        Unique identifier or number associated with the certification.  # noqa: E501

        :return: The certification_number of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: str
        """
        return self._certification_number

    @certification_number.setter
    def certification_number(self, certification_number):
        """Sets the certification_number of this UpdateCertificationRequestCertifications.

        Unique identifier or number associated with the certification.  # noqa: E501

        :param certification_number: The certification_number of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: str
        """

        self._certification_number = certification_number

    @property
    def name(self):
        """Gets the name of this UpdateCertificationRequestCertifications.  # noqa: E501

        Name or title of the certification.  # noqa: E501

        :return: The name of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateCertificationRequestCertifications.

        Name or title of the certification.  # noqa: E501

        :param name: The name of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def institute(self):
        """Gets the institute of this UpdateCertificationRequestCertifications.  # noqa: E501

        Institute or organization that issued the certification.  # noqa: E501

        :return: The institute of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: str
        """
        return self._institute

    @institute.setter
    def institute(self, institute):
        """Sets the institute of this UpdateCertificationRequestCertifications.

        Institute or organization that issued the certification.  # noqa: E501

        :param institute: The institute of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: str
        """

        self._institute = institute

    @property
    def description(self):
        """Gets the description of this UpdateCertificationRequestCertifications.  # noqa: E501

        Description or details of the certification.  # noqa: E501

        :return: The description of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateCertificationRequestCertifications.

        Description or details of the certification.  # noqa: E501

        :param description: The description of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def state(self):
        """Gets the state of this UpdateCertificationRequestCertifications.  # noqa: E501

        State or location where the certification was issued.  # noqa: E501

        :return: The state of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this UpdateCertificationRequestCertifications.

        State or location where the certification was issued.  # noqa: E501

        :param state: The state of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def issued_date(self):
        """Gets the issued_date of this UpdateCertificationRequestCertifications.  # noqa: E501


        :return: The issued_date of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: UpdateCertificationRequestIssuedDate
        """
        return self._issued_date

    @issued_date.setter
    def issued_date(self, issued_date):
        """Sets the issued_date of this UpdateCertificationRequestCertifications.


        :param issued_date: The issued_date of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: UpdateCertificationRequestIssuedDate
        """

        self._issued_date = issued_date

    @property
    def expiry_date(self):
        """Gets the expiry_date of this UpdateCertificationRequestCertifications.  # noqa: E501


        :return: The expiry_date of this UpdateCertificationRequestCertifications.  # noqa: E501
        :rtype: UpdateCertificationRequestExpiryDate
        """
        return self._expiry_date

    @expiry_date.setter
    def expiry_date(self, expiry_date):
        """Sets the expiry_date of this UpdateCertificationRequestCertifications.


        :param expiry_date: The expiry_date of this UpdateCertificationRequestCertifications.  # noqa: E501
        :type: UpdateCertificationRequestExpiryDate
        """

        self._expiry_date = expiry_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCertificationRequestCertifications, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCertificationRequestCertifications):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class NextHiringStatusDataHiringStatusList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'is_rejected': 'bool',
        'is_default': 'bool',
        'status_code': 'str',
        'step': 'str',
        'transition_statuses': 'list[NextHiringStatusDataTransitionStatuses]'
    }

    attribute_map = {
        'name': 'name',
        'is_rejected': 'isRejected',
        'is_default': 'isDefault',
        'status_code': 'statusCode',
        'step': 'step',
        'transition_statuses': 'transitionStatuses'
    }

    def __init__(self, name=None, is_rejected=None, is_default=None, status_code=None, step=None, transition_statuses=None):  # noqa: E501
        """NextHiringStatusDataHiringStatusList - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._is_rejected = None
        self._is_default = None
        self._status_code = None
        self._step = None
        self._transition_statuses = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if is_rejected is not None:
            self.is_rejected = is_rejected
        if is_default is not None:
            self.is_default = is_default
        if status_code is not None:
            self.status_code = status_code
        if step is not None:
            self.step = step
        if transition_statuses is not None:
            self.transition_statuses = transition_statuses

    @property
    def name(self):
        """Gets the name of this NextHiringStatusDataHiringStatusList.  # noqa: E501

        Name of the hiring status.  # noqa: E501

        :return: The name of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NextHiringStatusDataHiringStatusList.

        Name of the hiring status.  # noqa: E501

        :param name: The name of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def is_rejected(self):
        """Gets the is_rejected of this NextHiringStatusDataHiringStatusList.  # noqa: E501

        Flag indicating whether the hiring status is rejected.  # noqa: E501

        :return: The is_rejected of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejected

    @is_rejected.setter
    def is_rejected(self, is_rejected):
        """Sets the is_rejected of this NextHiringStatusDataHiringStatusList.

        Flag indicating whether the hiring status is rejected.  # noqa: E501

        :param is_rejected: The is_rejected of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :type: bool
        """

        self._is_rejected = is_rejected

    @property
    def is_default(self):
        """Gets the is_default of this NextHiringStatusDataHiringStatusList.  # noqa: E501

        Flag indicating whether the hiring status is the default.  # noqa: E501

        :return: The is_default of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this NextHiringStatusDataHiringStatusList.

        Flag indicating whether the hiring status is the default.  # noqa: E501

        :param is_default: The is_default of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def status_code(self):
        """Gets the status_code of this NextHiringStatusDataHiringStatusList.  # noqa: E501

        Status code of the hiring status.  # noqa: E501

        :return: The status_code of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this NextHiringStatusDataHiringStatusList.

        Status code of the hiring status.  # noqa: E501

        :param status_code: The status_code of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :type: str
        """

        self._status_code = status_code

    @property
    def step(self):
        """Gets the step of this NextHiringStatusDataHiringStatusList.  # noqa: E501

        Current step in the workflow for the hiring status.  # noqa: E501

        :return: The step of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :rtype: str
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this NextHiringStatusDataHiringStatusList.

        Current step in the workflow for the hiring status.  # noqa: E501

        :param step: The step of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :type: str
        """

        self._step = step

    @property
    def transition_statuses(self):
        """Gets the transition_statuses of this NextHiringStatusDataHiringStatusList.  # noqa: E501

        List of transition statuses for the current hiring status.  # noqa: E501

        :return: The transition_statuses of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :rtype: list[NextHiringStatusDataTransitionStatuses]
        """
        return self._transition_statuses

    @transition_statuses.setter
    def transition_statuses(self, transition_statuses):
        """Sets the transition_statuses of this NextHiringStatusDataHiringStatusList.

        List of transition statuses for the current hiring status.  # noqa: E501

        :param transition_statuses: The transition_statuses of this NextHiringStatusDataHiringStatusList.  # noqa: E501
        :type: list[NextHiringStatusDataTransitionStatuses]
        """

        self._transition_statuses = transition_statuses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NextHiringStatusDataHiringStatusList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NextHiringStatusDataHiringStatusList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class BadRequestError(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'errors': 'list[BadRequestErrorErrors]'
    }

    attribute_map = {
        'status': 'status',
        'errors': 'errors'
    }

    def __init__(self, status=None, errors=None):  # noqa: E501
        """BadRequestError - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._errors = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if errors is not None:
            self.errors = errors

    @property
    def status(self):
        """Gets the status of this BadRequestError.  # noqa: E501

        The status of the error response.  # noqa: E501

        :return: The status of this BadRequestError.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BadRequestError.

        The status of the error response.  # noqa: E501

        :param status: The status of this BadRequestError.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def errors(self):
        """Gets the errors of this BadRequestError.  # noqa: E501

        An array containing details of errors.  # noqa: E501

        :return: The errors of this BadRequestError.  # noqa: E501
        :rtype: list[BadRequestErrorErrors]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BadRequestError.

        An array containing details of errors.  # noqa: E501

        :param errors: The errors of this BadRequestError.  # noqa: E501
        :type: list[BadRequestErrorErrors]
        """

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BadRequestError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BadRequestError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class TaskDetailsResponseDataJobsInfo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'job_location': 'str',
        'job_title': 'str',
        'user_role': 'str',
        'no_of_pending_tasks': 'float'
    }

    attribute_map = {
        'job_id': 'jobId',
        'job_location': 'jobLocation',
        'job_title': 'jobTitle',
        'user_role': 'userRole',
        'no_of_pending_tasks': 'noOfPendingTasks'
    }

    def __init__(self, job_id=None, job_location=None, job_title=None, user_role=None, no_of_pending_tasks=None):  # noqa: E501
        """TaskDetailsResponseDataJobsInfo - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._job_location = None
        self._job_title = None
        self._user_role = None
        self._no_of_pending_tasks = None
        self.discriminator = None
        if job_id is not None:
            self.job_id = job_id
        if job_location is not None:
            self.job_location = job_location
        if job_title is not None:
            self.job_title = job_title
        if user_role is not None:
            self.user_role = user_role
        if no_of_pending_tasks is not None:
            self.no_of_pending_tasks = no_of_pending_tasks

    @property
    def job_id(self):
        """Gets the job_id of this TaskDetailsResponseDataJobsInfo.  # noqa: E501

        The job's reference id.  # noqa: E501

        :return: The job_id of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this TaskDetailsResponseDataJobsInfo.

        The job's reference id.  # noqa: E501

        :param job_id: The job_id of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def job_location(self):
        """Gets the job_location of this TaskDetailsResponseDataJobsInfo.  # noqa: E501

        The job's location.  # noqa: E501

        :return: The job_location of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :rtype: str
        """
        return self._job_location

    @job_location.setter
    def job_location(self, job_location):
        """Sets the job_location of this TaskDetailsResponseDataJobsInfo.

        The job's location.  # noqa: E501

        :param job_location: The job_location of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :type: str
        """

        self._job_location = job_location

    @property
    def job_title(self):
        """Gets the job_title of this TaskDetailsResponseDataJobsInfo.  # noqa: E501

        The job's title.  # noqa: E501

        :return: The job_title of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this TaskDetailsResponseDataJobsInfo.

        The job's title.  # noqa: E501

        :param job_title: The job_title of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def user_role(self):
        """Gets the user_role of this TaskDetailsResponseDataJobsInfo.  # noqa: E501

        The user's role to the job.  # noqa: E501

        :return: The user_role of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_role

    @user_role.setter
    def user_role(self, user_role):
        """Sets the user_role of this TaskDetailsResponseDataJobsInfo.

        The user's role to the job.  # noqa: E501

        :param user_role: The user_role of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :type: str
        """

        self._user_role = user_role

    @property
    def no_of_pending_tasks(self):
        """Gets the no_of_pending_tasks of this TaskDetailsResponseDataJobsInfo.  # noqa: E501

        The number of pending tasks associated with a given task in this job for the user.  # noqa: E501

        :return: The no_of_pending_tasks of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :rtype: float
        """
        return self._no_of_pending_tasks

    @no_of_pending_tasks.setter
    def no_of_pending_tasks(self, no_of_pending_tasks):
        """Sets the no_of_pending_tasks of this TaskDetailsResponseDataJobsInfo.

        The number of pending tasks associated with a given task in this job for the user.  # noqa: E501

        :param no_of_pending_tasks: The no_of_pending_tasks of this TaskDetailsResponseDataJobsInfo.  # noqa: E501
        :type: float
        """

        self._no_of_pending_tasks = no_of_pending_tasks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaskDetailsResponseDataJobsInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskDetailsResponseDataJobsInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.tags.tags_api import TagsApi
from phenom.api.tags.candidates_api import CandidatesApi

class Tags(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def tags_api(self):
        return TagsApi(self.__token, self.__gateway_url, self.__apikey)

    def candidates_api(self):
        return CandidatesApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AssignCandidatesToJobRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'candidate_ids': 'list[str]',
        'job_id': 'str',
        'sync_to_ats': 'bool',
        'push_to_ats': 'bool'
    }

    attribute_map = {
        'candidate_ids': 'candidateIds',
        'job_id': 'jobId',
        'sync_to_ats': 'syncToATS',
        'push_to_ats': 'pushToATS'
    }

    def __init__(self, candidate_ids=None, job_id=None, sync_to_ats=None, push_to_ats=None):  # noqa: E501
        """AssignCandidatesToJobRequest - a model defined in Swagger"""  # noqa: E501
        self._candidate_ids = None
        self._job_id = None
        self._sync_to_ats = None
        self._push_to_ats = None
        self.discriminator = None
        if candidate_ids is not None:
            self.candidate_ids = candidate_ids
        if job_id is not None:
            self.job_id = job_id
        if sync_to_ats is not None:
            self.sync_to_ats = sync_to_ats
        if push_to_ats is not None:
            self.push_to_ats = push_to_ats

    @property
    def candidate_ids(self):
        """Gets the candidate_ids of this AssignCandidatesToJobRequest.  # noqa: E501

        An array of candidate IDs to be assigned to the specified job.  # noqa: E501

        :return: The candidate_ids of this AssignCandidatesToJobRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._candidate_ids

    @candidate_ids.setter
    def candidate_ids(self, candidate_ids):
        """Sets the candidate_ids of this AssignCandidatesToJobRequest.

        An array of candidate IDs to be assigned to the specified job.  # noqa: E501

        :param candidate_ids: The candidate_ids of this AssignCandidatesToJobRequest.  # noqa: E501
        :type: list[str]
        """

        self._candidate_ids = candidate_ids

    @property
    def job_id(self):
        """Gets the job_id of this AssignCandidatesToJobRequest.  # noqa: E501

        The unique identifier of the job to which candidates are to be assigned.  # noqa: E501

        :return: The job_id of this AssignCandidatesToJobRequest.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this AssignCandidatesToJobRequest.

        The unique identifier of the job to which candidates are to be assigned.  # noqa: E501

        :param job_id: The job_id of this AssignCandidatesToJobRequest.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def sync_to_ats(self):
        """Gets the sync_to_ats of this AssignCandidatesToJobRequest.  # noqa: E501

        A boolean indicating whether the assignment should be synchronized with the Applicant Tracking System (ATS).  # noqa: E501

        :return: The sync_to_ats of this AssignCandidatesToJobRequest.  # noqa: E501
        :rtype: bool
        """
        return self._sync_to_ats

    @sync_to_ats.setter
    def sync_to_ats(self, sync_to_ats):
        """Sets the sync_to_ats of this AssignCandidatesToJobRequest.

        A boolean indicating whether the assignment should be synchronized with the Applicant Tracking System (ATS).  # noqa: E501

        :param sync_to_ats: The sync_to_ats of this AssignCandidatesToJobRequest.  # noqa: E501
        :type: bool
        """

        self._sync_to_ats = sync_to_ats

    @property
    def push_to_ats(self):
        """Gets the push_to_ats of this AssignCandidatesToJobRequest.  # noqa: E501

        A boolean indicating whether the assigned candidates should be pushed to the Applicant Tracking System (ATS).  # noqa: E501

        :return: The push_to_ats of this AssignCandidatesToJobRequest.  # noqa: E501
        :rtype: bool
        """
        return self._push_to_ats

    @push_to_ats.setter
    def push_to_ats(self, push_to_ats):
        """Sets the push_to_ats of this AssignCandidatesToJobRequest.

        A boolean indicating whether the assigned candidates should be pushed to the Applicant Tracking System (ATS).  # noqa: E501

        :param push_to_ats: The push_to_ats of this AssignCandidatesToJobRequest.  # noqa: E501
        :type: bool
        """

        self._push_to_ats = push_to_ats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssignCandidatesToJobRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssignCandidatesToJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobRecommendation(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'locale': 'str',
        'site_type': 'str',
        'user_type': 'str',
        'user_id': 'str',
        'user_profile': 'UserProfile',
        'max_recommendation_size': 'int'
    }

    attribute_map = {
        'locale': 'locale',
        'site_type': 'siteType',
        'user_type': 'userType',
        'user_id': 'userId',
        'user_profile': 'userProfile',
        'max_recommendation_size': 'maxRecommendationSize'
    }

    def __init__(self, locale=None, site_type='external', user_type='external', user_id=None, user_profile=None, max_recommendation_size=None):  # noqa: E501
        """JobRecommendation - a model defined in Swagger"""  # noqa: E501
        self._locale = None
        self._site_type = None
        self._user_type = None
        self._user_id = None
        self._user_profile = None
        self._max_recommendation_size = None
        self.discriminator = None
        if locale is not None:
            self.locale = locale
        if site_type is not None:
            self.site_type = site_type
        if user_type is not None:
            self.user_type = user_type
        if user_id is not None:
            self.user_id = user_id
        if user_profile is not None:
            self.user_profile = user_profile
        if max_recommendation_size is not None:
            self.max_recommendation_size = max_recommendation_size

    @property
    def locale(self):
        """Gets the locale of this JobRecommendation.  # noqa: E501

        Locale of the site (Language_Country) - Example: en_US.  # noqa: E501

        :return: The locale of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobRecommendation.

        Locale of the site (Language_Country) - Example: en_US.  # noqa: E501

        :param locale: The locale of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def site_type(self):
        """Gets the site_type of this JobRecommendation.  # noqa: E501

        Persona Value - Example: Internal, External.  # noqa: E501

        :return: The site_type of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobRecommendation.

        Persona Value - Example: Internal, External.  # noqa: E501

        :param site_type: The site_type of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._site_type = site_type

    @property
    def user_type(self):
        """Gets the user_type of this JobRecommendation.  # noqa: E501

        Type of the user - Internal or External User.  # noqa: E501

        :return: The user_type of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this JobRecommendation.

        Type of the user - Internal or External User.  # noqa: E501

        :param user_type: The user_type of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    @property
    def user_id(self):
        """Gets the user_id of this JobRecommendation.  # noqa: E501

        Unique identified for a user.  # noqa: E501

        :return: The user_id of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this JobRecommendation.

        Unique identified for a user.  # noqa: E501

        :param user_id: The user_id of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_profile(self):
        """Gets the user_profile of this JobRecommendation.  # noqa: E501


        :return: The user_profile of this JobRecommendation.  # noqa: E501
        :rtype: UserProfile
        """
        return self._user_profile

    @user_profile.setter
    def user_profile(self, user_profile):
        """Sets the user_profile of this JobRecommendation.


        :param user_profile: The user_profile of this JobRecommendation.  # noqa: E501
        :type: UserProfile
        """

        self._user_profile = user_profile

    @property
    def max_recommendation_size(self):
        """Gets the max_recommendation_size of this JobRecommendation.  # noqa: E501

        Maximum recommendations to be provided in response.  # noqa: E501

        :return: The max_recommendation_size of this JobRecommendation.  # noqa: E501
        :rtype: int
        """
        return self._max_recommendation_size

    @max_recommendation_size.setter
    def max_recommendation_size(self, max_recommendation_size):
        """Sets the max_recommendation_size of this JobRecommendation.

        Maximum recommendations to be provided in response.  # noqa: E501

        :param max_recommendation_size: The max_recommendation_size of this JobRecommendation.  # noqa: E501
        :type: int
        """

        self._max_recommendation_size = max_recommendation_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobRecommendation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobRecommendation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class HiringStatusData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'applications': 'HiringStatusDataApplications'
    }

    attribute_map = {
        'applications': 'applications'
    }

    def __init__(self, applications=None):  # noqa: E501
        """HiringStatusData - a model defined in Swagger"""  # noqa: E501
        self._applications = None
        self.discriminator = None
        if applications is not None:
            self.applications = applications

    @property
    def applications(self):
        """Gets the applications of this HiringStatusData.  # noqa: E501


        :return: The applications of this HiringStatusData.  # noqa: E501
        :rtype: HiringStatusDataApplications
        """
        return self._applications

    @applications.setter
    def applications(self, applications):
        """Sets the applications of this HiringStatusData.


        :param applications: The applications of this HiringStatusData.  # noqa: E501
        :type: HiringStatusDataApplications
        """

        self._applications = applications

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HiringStatusData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HiringStatusData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobResponseOnet(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'onet_code': 'str',
        'onet_title': 'str',
        'score': 'float'
    }

    attribute_map = {
        'onet_code': 'onetCode',
        'onet_title': 'onetTitle',
        'score': 'score'
    }

    def __init__(self, onet_code=None, onet_title=None, score=None):  # noqa: E501
        """JobResponseOnet - a model defined in Swagger"""  # noqa: E501
        self._onet_code = None
        self._onet_title = None
        self._score = None
        self.discriminator = None
        if onet_code is not None:
            self.onet_code = onet_code
        if onet_title is not None:
            self.onet_title = onet_title
        if score is not None:
            self.score = score

    @property
    def onet_code(self):
        """Gets the onet_code of this JobResponseOnet.  # noqa: E501

        Job special code according O*NET standard.  # noqa: E501

        :return: The onet_code of this JobResponseOnet.  # noqa: E501
        :rtype: str
        """
        return self._onet_code

    @onet_code.setter
    def onet_code(self, onet_code):
        """Sets the onet_code of this JobResponseOnet.

        Job special code according O*NET standard.  # noqa: E501

        :param onet_code: The onet_code of this JobResponseOnet.  # noqa: E501
        :type: str
        """

        self._onet_code = onet_code

    @property
    def onet_title(self):
        """Gets the onet_title of this JobResponseOnet.  # noqa: E501

        Job special title according O*NET standard.  # noqa: E501

        :return: The onet_title of this JobResponseOnet.  # noqa: E501
        :rtype: str
        """
        return self._onet_title

    @onet_title.setter
    def onet_title(self, onet_title):
        """Sets the onet_title of this JobResponseOnet.

        Job special title according O*NET standard.  # noqa: E501

        :param onet_title: The onet_title of this JobResponseOnet.  # noqa: E501
        :type: str
        """

        self._onet_title = onet_title

    @property
    def score(self):
        """Gets the score of this JobResponseOnet.  # noqa: E501

        O*NET score.  # noqa: E501

        :return: The score of this JobResponseOnet.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this JobResponseOnet.

        O*NET score.  # noqa: E501

        :param score: The score of this JobResponseOnet.  # noqa: E501
        :type: float
        """

        self._score = score

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobResponseOnet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponseOnet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
